;; Generated package description from kubed.el  -*- no-byte-compile: t -*-
(define-package "kubed" "0.3.2.0.20240821.164727" "Kubernetes, Emacs, done!" '((emacs "29.1")) :commit "37a7fa4cfcf6beb9f2ee195ee8f7ad6e4ad58055" :authors '(("Eshel Yaron" . "me@eshelyaron.com")) :maintainer '("Eshel Yaron" . "~eshel/kubed-devel@lists.sr.ht") :keywords '("tools" "kubernetes" "containers") :url "https://eshelyaron.com/kubed.html")
